@@ -19,6 +19,7 @@ class OpenThermGateway:  # pylint: disable=too-many-public-methods
         self._transport = None
         self._protocol = None
         self._gpio_task = None
+        self._skip_init = False
         self.status = StatusManager()
         self.connection = ConnectionManager(self)
 
@@ -34,21 +35,27 @@ class OpenThermGateway:  # pylint: disable=too-many-public-methods
         self,
         port,
         timeout=None,
+        skip_init=None,
     ):
         """
         Connect to Opentherm Gateway at @port.
         Initialize the parameters obtained from the PS= and PR=
         commands and returns the status dict with the obtained values
         or False if cancelled.
+        If @skip_init is True, the PS= and PR= commands are skipped and only PS=0 is
+        sent upon this and future connection attempts.
         If called while connected, reconnect to the gateway.
 
         This method is a coroutine
         """
+        if skip_init is not None:
+            self._skip_init = skip_init
         if not await self.connection.connect(port, timeout):
             return False
         self._protocol = self.connection.protocol
-        await self.get_reports()
-        await self.get_status()
+        if not self._skip_init:
+            await self.get_reports()
+            await self.get_status()
         await self._poll_gpio()
         return self.status.status
 
